@@ -10,8 +10,8 @@ EXTERN_C void
 xs_init(pTHX) {
     char *file = __FILE__;
     dXSUB_SYS;
-    newXS("DynaLoader::boot_DynaLoader", boot_DynaLoader, file);
-    newXS("Socket::bootstrap", boot_Socket, file);
+    // newXS("DynaLoader::boot_DynaLoader", boot_DynaLoader, file);
+    // newXS("Socket::bootstrap", boot_Socket, file);
 }
 
 void* 
